<?php

namespace Litecms\MarketingTool\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\MarketingTool\Http\Requests\MarketingToolRequest;
use Litecms\MarketingTool\Interfaces\MarketingToolRepositoryInterface;
use Litecms\MarketingTool\Models\MarketingTool;

/**
 * Resource controller class for marketing_tool.
 */
class MarketingToolResourceController extends BaseController
{

    /**
     * Initialize marketing_tool resource controller.
     *
     * @param type MarketingToolRepositoryInterface $marketing_tool
     *
     * @return null
     */
    public function __construct(MarketingToolRepositoryInterface $marketing_tool)
    {
        parent::__construct();
        $this->repository = $marketing_tool;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\MarketingTool\Repositories\Criteria\MarketingToolResourceCriteria::class);
    }

    /**
     * Display a list of marketing_tool.
     *
     * @return Response
     */
    public function index(MarketingToolRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\MarketingTool\Repositories\Presenter\MarketingToolPresenter::class)
                ->$function();
        }

        $marketing_tools = $this->repository->paginate();

        return $this->response->title(trans('marketing_tool::marketing_tool.names'))
            ->view('marketing_tool::marketing_tool.index', true)
            ->data(compact('marketing_tools'))
            ->output();
    }

    /**
     * Display marketing_tool.
     *
     * @param Request $request
     * @param Model   $marketing_tool
     *
     * @return Response
     */
    public function show(MarketingToolRequest $request, MarketingTool $marketing_tool)
    {

        if ($marketing_tool->exists) {
            $view = 'marketing_tool::marketing_tool.show';
        } else {
            $view = 'marketing_tool::marketing_tool.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('marketing_tool::marketing_tool.name'))
            ->data(compact('marketing_tool'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new marketing_tool.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(MarketingToolRequest $request)
    {

        $marketing_tool = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('marketing_tool::marketing_tool.name')) 
            ->view('marketing_tool::marketing_tool.create', true) 
            ->data(compact('marketing_tool'))
            ->output();
    }

    /**
     * Create new marketing_tool.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(MarketingToolRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $marketing_tool                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('marketing_tool::marketing_tool.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('marketing_tool/marketing_tool/' . $marketing_tool->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/marketing_tool/marketing_tool'))
                ->redirect();
        }

    }

    /**
     * Show marketing_tool for editing.
     *
     * @param Request $request
     * @param Model   $marketing_tool
     *
     * @return Response
     */
    public function edit(MarketingToolRequest $request, MarketingTool $marketing_tool)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('marketing_tool::marketing_tool.name'))
            ->view('marketing_tool::marketing_tool.edit', true)
            ->data(compact('marketing_tool'))
            ->output();
    }

    /**
     * Update the marketing_tool.
     *
     * @param Request $request
     * @param Model   $marketing_tool
     *
     * @return Response
     */
    public function update(MarketingToolRequest $request, MarketingTool $marketing_tool)
    {
        try {
            $attributes = $request->all();

            $marketing_tool->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('marketing_tool::marketing_tool.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('marketing_tool/marketing_tool/' . $marketing_tool->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('marketing_tool/marketing_tool/' . $marketing_tool->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the marketing_tool.
     *
     * @param Model   $marketing_tool
     *
     * @return Response
     */
    public function destroy(MarketingToolRequest $request, MarketingTool $marketing_tool)
    {
        try {

            $marketing_tool->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('marketing_tool::marketing_tool.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('marketing_tool/marketing_tool/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('marketing_tool/marketing_tool/' . $marketing_tool->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple marketing_tool.
     *
     * @param Model   $marketing_tool
     *
     * @return Response
     */
    public function delete(MarketingToolRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('marketing_tool::marketing_tool.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('marketing_tool/marketing_tool'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/marketing_tool/marketing_tool'))
                ->redirect();
        }

    }

    /**
     * Restore deleted marketing_tools.
     *
     * @param Model   $marketing_tool
     *
     * @return Response
     */
    public function restore(MarketingToolRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('marketing_tool::marketing_tool.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/marketing_tool/marketing_tool'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/marketing_tool/marketing_tool/'))
                ->redirect();
        }

    }

}
